from setuptools import setup

setup(name='distributionsbyme',
      version='0.1',
      description='Gaussian distributions',
      author='Maria',
      packages=['distributionsbyme'],
      zip_safe=False)
